@@ -17,10 +17,18 @@ class TagField(models.Field):
         self.tag_args['max_tags'] = max_tags
 
     def get_internal_type(self):
-        return "CharField"
+        return "TextField"
 
-    def get_prep_value(self, value):
-        return self.delimiters.join(value)
+    def from_db_value(self, value, expression, connection):
+        return self.to_python(value)
+
+    def to_python(self, value):
+        value = super(TagField, self).to_python(value)
+        if isinstance(value, list):
+            return value
+        if value is None:
+            return []
+        return value.split(self.delimiters)
 
     def get_db_prep_value(self, value, connection, prepared=False):
         return self.delimiters.join(value)
